@@ -3,24 +3,35 @@ package Sumu::Perl::Modules;
 # ABSTRACT: Perl Modules
 
 =head1 NAME
+
     Perl Modules
-=cut
 
 =head1 VERSION
 
-version 0.1.5
+version 0.2.8
+
+=head2 DESC
+
+    List all installed Perl Modules on your system
+    
+=cut
 
 =head2 Strictures
+
     Enable strict and warnings
+
 =cut
 
 use strict;
 use warnings;
 
 =head2 VERSION
+
+    our VERSION = 'N.N.N'
+
 =cut
 
-our $VERSION = '0.1.5';
+our $VERSION = '0.2.8';
 
 use parent qw(Exporter); 
 require Exporter; 
@@ -41,6 +52,8 @@ sub NAME { my $self = shift; my $NAME = "Perl Modules"; return $NAME; }
 
 =head3 Sub new
 
+    Bless the classes 
+
 =cut
 
 sub new {
@@ -50,12 +63,16 @@ sub new {
 }
 
 
-=head3 Required Modules, CPAN
+=head3 Required Modules
+
     ExtUtils::Installed
+
 =cut
 
 use ExtUtils::Installed;
 
+my $inst = ExtUtils::Installed->new();
+
 
 =head3 Sub _extutils
     Returns List of modules 
@@ -64,8 +81,6 @@ use ExtUtils::Installed;
 sub _extutils {
 
     my $c = shift;
-    
-    my $inst = ExtUtils::Installed->new();
 
     my @modules = $inst->modules();
 
@@ -106,7 +121,11 @@ sub _extutils {
 
 
 =head3 Sub _dirs 
-    Show/Get Dirs in a module 
+
+    Show/Get Dirs in a given module 
+
+    Returns an ordered list
+
 =cut
 
 sub _dirs  {
@@ -125,8 +144,6 @@ sub _dirs  {
 
     $module =~ s!\\!\/!g;
 
-    my $inst = ExtUtils::Installed->new();
-
     #
     my @mod_dirs = $inst->directories("$module");
 
@@ -165,8 +182,15 @@ sub _dirs  {
 }
 # end 
 
+
 =head3 Sub _doc
-    Show Doc for a module 
+
+    Show Doc for a given module 
+
+    Module includes path 
+
+    Returns an ordered list 
+
 =cut
 
 sub _doc {
